/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PagerType } from './pager-type';
import { PageSizeItem } from './page-size-item';
import { PagerPosition } from './pager-position';
/**
 * The pager settings of the ListView
 * ([see example]({% slug paging_listview %}#toc-pager-options)).
 */
export interface PagerSettings {
    /**
     * Specifies the position of the pager.
     *
     * The possible values are:
     * - `bottom` (Default) &mdash; Positions the pager below the ListView.
     * - `top` &mdash; Positions the pager above the ListView.
     * - `both` &mdash; Displays two pager instances. Positions the first one above the ListView and the second one below it.
     */
    position?: PagerPosition;
    /**
     * Sets the maximum numeric buttons count before the buttons are collapsed.
     */
    buttonCount?: number;
    /**
     * Toggles the information about the current page and the total number of records.
     */
    info?: boolean;
    /**
     * Toggles the Previous and Next buttons.
     */
    previousNext?: boolean;
    /**
     * Defines the type of the pager.
     */
    type?: PagerType;
    /**
     * Shows a dropdown for selecting the page size. When set to true, the dropdown will contain the default list of options - 5, 10, 20.
     * To customize the list of options, set `pageSizeValues` to an array of the desired values.
     * The array can contain numbers and `PageSizeItem` objects.
     */
    pageSizeValues?: boolean | number[] | PageSizeItem[];
}
